Use-Case Model
==============

This section includes the list of use cases we expected to have in the system.
Since the number of use cases is large, we divide the use cases to smaller groups
for clarity.

.. toctree::
   :maxdepth: 2

   collab
   academic
   other
